@@ -5,8 +5,7 @@ use super::messages::*;
 use super::parser;
 use super::rewrites::*;
 use super::roles_validation::{
-    validate_roles_config, ResultEvent, VALIDATE_ROLES_CONFIG_ACTOR_HAS_ROLE_FOR_RESOURCE,
-    VALIDATE_ROLES_CONFIG_RESOURCES,
+    validate_roles_config, ResultEvent, VALIDATE_ROLES_CONFIG_RESOURCES,
 };
 use super::rules::*;
 use super::runnable::Runnable;
@@ -317,14 +316,12 @@ impl Polar {
         let src_id = self.kb.read().unwrap().new_id();
         let term = parser::parse_query(src_id, VALIDATE_ROLES_CONFIG_RESOURCES)?;
         self.kb.write().unwrap().inline_queries.push(term);
-        let term = parser::parse_query(src_id, VALIDATE_ROLES_CONFIG_ACTOR_HAS_ROLE_FOR_RESOURCE)?;
-        self.kb.write().unwrap().inline_queries.push(term);
 
         result
     }
 
     pub fn validate_roles_config(&self, results: Vec<Vec<ResultEvent>>) -> PolarResult<()> {
-        validate_roles_config(results)
+        validate_roles_config(&self.kb.read().unwrap().rules, results)
     }
 }
 
